==> CGAL-4.10-doc_html.tar.xz: doc_html/BGL/annotated.js <==
var annotated =
[
    [ "CGAL", null, [
      [ "internal", null, null ],
      [ "HalfedgeDS_face_max_base_with_id", "classCGAL_1_1HalfedgeDS__face__max__base__with__id.html", "classCGAL_1_1HalfedgeDS__face__max__base__with__id" ],
      [ "HalfedgeDS_halfedge_max_base_with_id", "classCGAL_1_1HalfedgeDS__halfedge__max__base__with__id.html", "classCGAL_1_1HalfedgeDS__halfedge__max__base__with__id" ],
      [ "HalfedgeDS_vertex_max_base_with_id", "classCGAL_1_1HalfedgeDS__vertex__max__base__with__id.html", "classCGAL_1_1HalfedgeDS__vertex__max__base__with__id" ],
      [ "Polyhedron_items_with_id_3", "classCGAL_1_1Polyhedron__items__with__id__3.html", "classCGAL_1_1Polyhedron__items__with__id__3" ],
      [ "Triangulation_vertex_base_with_id_2", "classCGAL_1_1Triangulation__vertex__base__with__id__2.html", "classCGAL_1_1Triangulation__vertex__base__with__id__2" ],
      [ "Halfedge_around_source_iterator", "classCGAL_1_1Halfedge__around__source__iterator.html", null ],
      [ "Halfedge_around_target_iterator", "classCGAL_1_1Halfedge__around__target__iterator.html", null ],
      [ "Halfedge_around_face_iterator", "classCGAL_1_1Halfedge__around__face__iterator.html", null ],
      [ "Halfedge_around_target_circulator", "classCGAL_1_1Halfedge__around__target__circulator.html", null ],
      [ "Halfedge_around_source_circulator", "classCGAL_1_1Halfedge__around__source__circulator.html", null ],
      [ "Face_around_target_circulator", "classCGAL_1_1Face__around__target__circulator.html", null ],
      [ "Halfedge_around_face_circulator", "classCGAL_1_1Halfedge__around__face__circulator.html", null ],
      [ "Face_around_face_iterator", "classCGAL_1_1Face__around__face__iterator.html", null ],
      [ "Face_around_face_circulator", "classCGAL_1_1Face__around__face__circulator.html", null ],
      [ "Face_around_target_iterator", "classCGAL_1_1Face__around__target__iterator.html", null ],
      [ "Vertex_around_face_iterator", "classCGAL_1_1Vertex__around__face__iterator.html", null ],
      [ "Vertex_around_target_circulator", "classCGAL_1_1Vertex__around__target__circulator.html", null ],
      [ "Vertex_around_target_iterator", "classCGAL_1_1Vertex__around__target__iterator.html", null ],
      [ "Graph_with_descriptor_with_graph", "structCGAL_1_1Graph__with__descriptor__with__graph.html", null ],
      [ "Graph_with_descriptor_with_graph_property_map", "structCGAL_1_1Graph__with__descriptor__with__graph__property__map.html", null ],
      [ "Dual", "classCGAL_1_1Dual.html", "classCGAL_1_1Dual" ]
    ] ],
    [ "FaceGraph", "classFaceGraph.html", null ],
    [ "FaceListGraph", "classFaceListGraph.html", null ],
    [ "HalfedgeGraph", "classHalfedgeGraph.html", null ],
    [ "HalfedgeListGraph", "classHalfedgeListGraph.html", null ],
    [ "MutableFaceGraph", "classMutableFaceGraph.html", null ],
    [ "MutableHalfedgeGraph", "classMutableHalfedgeGraph.html", null ]
];

==> CGAL-4.11.3-doc_html.tar.xz: doc_html/BGL/annotated.js <==
var annotated =
[
    [ "boost", "namespaceboost.html", null ],
    [ "CGAL", null, [
      [ "HalfedgeDS_face_max_base_with_id", "classCGAL_1_1HalfedgeDS__face__max__base__with__id.html", "classCGAL_1_1HalfedgeDS__face__max__base__with__id" ],
      [ "HalfedgeDS_halfedge_max_base_with_id", "classCGAL_1_1HalfedgeDS__halfedge__max__base__with__id.html", "classCGAL_1_1HalfedgeDS__halfedge__max__base__with__id" ],
      [ "HalfedgeDS_vertex_max_base_with_id", "classCGAL_1_1HalfedgeDS__vertex__max__base__with__id.html", "classCGAL_1_1HalfedgeDS__vertex__max__base__with__id" ],
      [ "Linear_cell_complex_bgl_min_items", "classCGAL_1_1Linear__cell__complex__bgl__min__items.html", null ],
      [ "Linear_cell_complex_for_bgl_combinatorial_map_helper", "classCGAL_1_1Linear__cell__complex__for__bgl__combinatorial__map__helper.html", "classCGAL_1_1Linear__cell__complex__for__bgl__combinatorial__map__helper" ],
      [ "Polyhedron_items_with_id_3", "classCGAL_1_1Polyhedron__items__with__id__3.html", "classCGAL_1_1Polyhedron__items__with__id__3" ],
      [ "Triangulation_vertex_base_with_id_2", "classCGAL_1_1Triangulation__vertex__base__with__id__2.html", "classCGAL_1_1Triangulation__vertex__base__with__id__2" ],
      [ "Halfedge_around_source_iterator", "classCGAL_1_1Halfedge__around__source__iterator.html", null ],
      [ "Halfedge_around_target_iterator", "classCGAL_1_1Halfedge__around__target__iterator.html", null ],
      [ "Halfedge_around_face_iterator", "classCGAL_1_1Halfedge__around__face__iterator.html", null ],
      [ "Halfedge_around_target_circulator", "classCGAL_1_1Halfedge__around__target__circulator.html", null ],
      [ "Halfedge_around_source_circulator", "classCGAL_1_1Halfedge__around__source__circulator.html", null ],
      [ "Face_around_target_circulator", "classCGAL_1_1Face__around__target__circulator.html", null ],
      [ "Halfedge_around_face_circulator", "classCGAL_1_1Halfedge__around__face__circulator.html", null ],
      [ "Face_around_face_iterator", "classCGAL_1_1Face__around__face__iterator.html", null ],
      [ "Face_around_face_circulator", "classCGAL_1_1Face__around__face__circulator.html", null ],
      [ "Face_around_target_iterator", "classCGAL_1_1Face__around__target__iterator.html", null ],
      [ "Vertex_around_face_iterator", "classCGAL_1_1Vertex__around__face__iterator.html", null ],
      [ "Vertex_around_target_circulator", "classCGAL_1_1Vertex__around__target__circulator.html", null ],
      [ "Vertex_around_target_iterator", "classCGAL_1_1Vertex__around__target__iterator.html", null ],
      [ "Graph_with_descriptor_with_graph", "structCGAL_1_1Graph__with__descriptor__with__graph.html", null ],
      [ "Graph_with_descriptor_with_graph_property_map", "structCGAL_1_1Graph__with__descriptor__with__graph__property__map.html", null ],
      [ "Face_filtered_graph", "structCGAL_1_1Face__filtered__graph.html", "structCGAL_1_1Face__filtered__graph" ],
      [ "Dual", "classCGAL_1_1Dual.html", "classCGAL_1_1Dual" ],
      [ "Seam_mesh", "classCGAL_1_1Seam__mesh.html", "classCGAL_1_1Seam__mesh" ]
    ] ],
    [ "EdgeListGraph", "classEdgeListGraph.html", "classEdgeListGraph" ],
    [ "FaceGraph", "classFaceGraph.html", "classFaceGraph" ],
    [ "FaceListGraph", "classFaceListGraph.html", "classFaceListGraph" ],
    [ "HalfedgeGraph", "classHalfedgeGraph.html", "classHalfedgeGraph" ],
    [ "HalfedgeListGraph", "classHalfedgeListGraph.html", "classHalfedgeListGraph" ],
    [ "MutableFaceGraph", "classMutableFaceGraph.html", "classMutableFaceGraph" ],
    [ "MutableHalfedgeGraph", "classMutableHalfedgeGraph.html", "classMutableHalfedgeGraph" ],
    [ "VertexListGraph", "classVertexListGraph.html", "classVertexListGraph" ]
];
